*-- Before you integrate FRX2Any into your VFP application you should realize that FRX2Any
*-- requires GDIPlus.DLL which is freely available and can be installed on Win98 and higher.
*-- If you have not installed WinXP or .NET framework then you can download this DLL from
*-- http://www.microsoft.com/msdownload/platformsdk/sdkupdate/psdkredist.htm
*-- or
*-- http://www.dll-files.com/dllindex/dll-files.shtml?gdiplus


***************************************************************************************************************************
*-- OutPut options
***************************************************************************************************************************
#DEFINE cnOUTPUT_SCREEN			         				1
#DEFINE cnOUTPUT_PRINT			         				2
#DEFINE cnOUTPUT_EMAIL			         				3
#DEFINE cnOUTPUT_FILE		 	         				4

***************************************************************************************************************************
*-- Enumeration type for the various axis types that are available
***************************************************************************************************************************
#DEFINE cnCHART_AXIS_TYPE_LINERAL						0
#DEFINE cnCHART_AXIS_TYPE_LOG							1
#DEFINE cnCHART_AXIS_TYPE_DATE							2
#DEFINE cnCHART_AXIS_TYPE_TEXT							3
#DEFINE cnCHART_AXIS_TYPE_ORDINAL						4

***************************************************************************************************************************
*-- Enumeration type that defines the available types of BarItem
***************************************************************************************************************************
#DEFINE cnCHART_BARITEM_TYPE_CLUSTER					0
#DEFINE cnCHART_BARITEM_TYPE_OVERLAY					1
#DEFINE cnCHART_BARITEM_TYPE_SORTEDOVERLAY				2
#DEFINE cnCHART_BARITEM_TYPE_STACK						3
#DEFINE cnCHART_BARITEM_TYPE_PERCENTSTACK				4

***************************************************************************************************************************
*-- Enumeration type for the various symbol shapes that are available
***************************************************************************************************************************
#DEFINE cnCHART_SYMBOL_TYPE_SQUARE						0
#DEFINE cnCHART_SYMBOL_TYPE_DIAMOND						1
#DEFINE cnCHART_SYMBOL_TYPE_TRIANGLE					2
#DEFINE cnCHART_SYMBOL_TYPE_CIRCLE						3
#DEFINE cnCHART_SYMBOL_TYPE_XCROSS						4
#DEFINE cnCHART_SYMBOL_TYPE_PLUS						5
#DEFINE cnCHART_SYMBOL_TYPE_STAR						6
#DEFINE cnCHART_SYMBOL_TYPE_TRIANGLE_DOWN				7

***************************************************************************************************************************
*-- LinearGradient Mode
***************************************************************************************************************************
#DEFINE cnGDIPLUS_LINEARGRADIENTMODE_HORIZONTAL			0
#DEFINE cnGDIPLUS_LINEARGRADIENTMODE_VERTICAL			1
#DEFINE cnGDIPLUS_LINEARGRADIENTMODE_FORWARDDIAGONAL	2
#DEFINE cnGDIPLUS_LINEARGRADIENTMODE_BACKWARDDIAGONAL	3

***************************************************************************************************************************
*-- Enumeration type that defines how a curve is drawn
***************************************************************************************************************************
#DEFINE cnCHART_LINE_STEP_TYPE_FORWARD					0
#DEFINE cnCHART_LINE_STEP_TYPE_REARWARD					1
#DEFINE cnCHART_LINE_STEP_TYPE_NONE						2

***************************************************************************************************************************
*--	Enumeration type for the various axis date and time unit types that are available
***************************************************************************************************************************
#DEFINE cnCHART_DATE_UNIT_YEAR							0
#DEFINE cnCHART_DATE_UNIT_MONTH							1
#DEFINE cnCHART_DATE_UNIT_DAY							2
#DEFINE cnCHART_DATE_UNIT_HOUR							3
#DEFINE cnCHART_DATE_UNIT_MINUTE						4
#DEFINE cnCHART_DATE_UNIT_SECOND						5


PRIVATE loMonthlyChart

LOCAL laX
LOCAL laY

LOCAL loFile
LOCAL loYearlyChart
LOCAL loYearlyChartCurve
LOCAL loMonthlyChartCurve


LOCAL lcOutPutFileName
LOCAL lcOutPutFilePath
LOCAL lcReportFullName
LOCAL lcDBFPath

LOCAL lnYear
LOCAL lnMonth
LOCAL lnDay


DIMENSION laX[1]
DIMENSION laY[1]


CD LEFT(SYS(16,0), RAT('\', SYS(16,0)))

SET PATH TO  ..\..\..\

lcReportFullName = FULLPATH('..\..\Reports\SalesReportWithManyCharts.FRX')

IF !FILE(lcReportFullName)
	=MESSAGEBOX('File ' + lcReportFullName + ' does not exist.', 16, 'Error')
ELSE

	lcDBFPath		 = FULLPATH('..\..\Reports\SalesReportWithManyCharts.DBF')

	lcOutPutFileName = JUSTSTEM(lcReportFullName)
	lcOutPutFilePath = JUSTPATH(SYS(16,0)) + '\OutPut\'

	SET CLASSLIB TO FRX2Any IN FRX2Any.APP 

	loFile = CREATEOBJECT('PDFFile')	

	IF TYPE('loFile') = 'O'

		WITH loFile
*-- Unlock FRX2Any
			.UNLOCK('xxxxxx-xxxxxx-xxxxxx-xxxxxx-xxxxxx-xxxxxx')

*-- NOTE: loFile.cExportFileName should not include file extension. For example: loFile.cExportFileName = 'ReportOutput'
			.cExportFileName = lcOutPutFileName

*-- NOTE: loFile.cSaveFolder should contain only path to the output file. For example: loFile.cSaveFolder = 'c:\MyApp\MyOutPut\'
			.cSaveFolder     = lcOutPutFilePath

*-- Specifies that output file will be displayed after creation
			.nOutPutType     = cnOUTPUT_SCREEN
			
			
			.lDisplayStatus = .T.
			
*-- Chart will be drawn in the Title band.
*-- 'Yearly Chart place keeper' - is an unique name of the Chart, which must be placed in a Comment field of the Box oject
*-- used as a 'place keeper' and which will be replaced by Chart.
			loYearlyChart = .AddChart('Yearly Chart place keeper')

*-- Specify Chart's properties
*-- For description of all Chart's properties and methods, please see FRX2Any help file.
			WITH loYearlyChart.oPanel
*-- Set the main Title of the Chart
				.cTitle = 'Sales by Year (1997)'

				WITH .oPanelBorder
					.lVisible   = .F.
				ENDWITH

				WITH .oFontSpec
					.cFamily   = 'Arial Black'
				ENDWITH

*-- Set a background color to the Chart panel frame
				WITH .oPanelFill
*-- Create a linear gradient color-fill
					.SetGradientFill(RGB(255,255,255), RGB(208,224,244), 2)
				ENDWITH

*-- Set a background color to the axis frame
				WITH .oAxisFill
*-- Create a linear gradient color-fill
					.SetGradientFill(RGB(255,255,255), RGB(249, 253, 200), 2)
				ENDWITH

*-- Set Title for X axis
				WITH .oXAxis
*-- Set the X axis title.
					.cTitle     = 'Time, Month'
					.nType      = cnCHART_AXIS_TYPE_DATE

*-- Sets the minimum scale value for this X axis. By default this value is set automatically.
					.nScaleMin = .oXDate.CalendarDateToXLDate(1997, 01, 01)
*-- Sets the maximum scale value for this X axis. By default this value is set automatically.
					.nScaleMax = .oXDate.CalendarDateToXLDate(1997, 12, 01)


					WITH .oScaleFontSpec
						.nAngle = 315
						.nSize  = 10
					ENDWITH

				ENDWITH

*-- Set Title for Y axis
				WITH .oYAxis
*-- Set the Y axis title.
					.cTitle     = 'Sales, $'
					.lShowGrid  = .T.

					WITH .oScaleFontSpec
						.nAngle = 135
						.nSize  = 10
					ENDWITH

				ENDWITH

*-- Make up data points
				lnYear = 1997

				SELECT MONTH(DATE) AS MONTH, SUM(Sale) AS Sale FROM (lcDBFPath) WHERE YEAR(DATE) = lnYear  GROUP BY 1 INTO CURSOR 'cChartPoints'

				GO TOP

				DO WHILE !EOF()
*-- X Axis points
*-- Calculate an XL Date from the specified Calendar date (year, month, day, hour, minute, second)
					lnlXLDate = .oXAxis.oXDate.CalendarDateToXLDate(lnYear, MONTH)

					IF !EMPTY(laX[1])
						DIMENSION laX[ALEN(laX, 1) + 1]
					ENDIF

					IF !EMPTY(laY[1])
						DIMENSION laY[ALEN(laY, 1) + 1]
					ENDIF


					laX[ALEN(laX, 1)] = lnlXLDate
					laY[ALEN(laY, 1)] = cChartPoints.Sale

					SKIP
				ENDDO

				loYearlyChartCurve = .AddCurve('Sales', @laX, @laY, RGB(255,55,205), cnCHART_SYMBOL_TYPE_CIRCLE)

				IF !ISNULL(loYearlyChartCurve)

					WITH loYearlyChartCurve

						WITH .oLine

							.nWidth    = 1
							.nStepType = cnCHART_LINE_STEP_TYPE_FORWARD

							WITH .oFill
								.SetGradientFill(RGB(255,255,255), RGB(255,155,205), cnGDIPLUS_LINEARGRADIENTMODE_FORWARDDIAGONAL, 200)
							ENDWITH

						ENDWITH

						WITH .oSymbol
*-- Set the size of the Symbol, value Size in pixels
							.nSize = 10

							WITH .oFill
*-- Create a linear gradient color-fill
								.SetSolidFill(RGB(255, 255, 255))
							ENDWITH

						ENDWITH

					ENDWITH

				ENDIF

			ENDWITH

*-- Chart will be drawn in the Group Header band.
*-- 'Monthly Chart place keeper' - is an unique name of the Chart, which must be placed in a Comment field of the Box oject
*-- used as a 'place keeper' and which will be replaced by Chart.
			loMonthlyChart = .AddChart('Monthly Chart place keeper')

*-- Specify Chart's properties
*-- For description of all Chart's properties and methods, please see FRX2Any help file.
			WITH loMonthlyChart.oPanel
*-- Set the main Title of the Chart
				WITH .oPanelBorder
					.lVisible   = .F.
				ENDWITH

				WITH .oFontSpec
					.cFamily   = 'Arial Black'
				ENDWITH

*-- Set a background color to the Chart panel frame
				WITH .oPanelFill
*-- Create a linear gradient color-fill
					.SetGradientFill(RGB(255,255,255), RGB(208,224,244), 2)
				ENDWITH

*-- Set a background color to the axis frame
				WITH .oAxisFill
*-- Create a linear gradient color-fill
					.SetGradientFill(RGB(255,255,255), RGB(249, 253, 200), 2)
				ENDWITH

*-- Set Title for X axis
				WITH .oXAxis
*-- Set the X axis title.
					.cTitle     = 'Time, Days'
					.nType      = cnCHART_AXIS_TYPE_DATE

					WITH .oScaleFontSpec
						.nAngle = 315
						.nSize  = 10
					ENDWITH

				ENDWITH

*-- Set Title for Y axis
				WITH .oYAxis
*-- Set the Y axis title.
					.cTitle     = 'Sales, $'
					.lShowGrid  = .T.

					WITH .oScaleFontSpec
						.nAngle = 135
						.nSize  = 10
					ENDWITH

				ENDWITH

			ENDWITH


*-- Create cursor for Report details
			SELECT * FROM (lcDBFPath) WHERE YEAR(DATE)=1997 ORDER BY DATE INTO CURSOR 'cChartDetails'

			.SAVE(lcReportFullName)

			.RELEASE()

			USE IN 'SalesReportWithManyCharts'
			USE IN 'cChartPoints'
			USE IN 'cChartDetails'

		ENDWITH

	ENDIF
ENDIF


*-- Called as 'On Entry' function of Group Header
FUNCTION SetMonthChart(tdDate)

	LOCAL laX
	LOCAL laY

	LOCAL loMonthlyChartCurve

	LOCAL lcDBFPath

	LOCAL lnYear
	LOCAL lnMonth
	
	
	DIMENSION laX[1]
	DIMENSION laY[1]

	lnYear    = 1997
	lnMonth   = MONTH(tdDate)

	lcDBFPath = FULLPATH('..\..\Reports\SalesReportWithManyCharts.DBF')

	WITH loMonthlyChart.oPanel
*-- Set the main Title of the Chart
		.cTitle = 'Sales by Month (' + CMONTH(tdDate) + ')'

		lnSelect = SELECT()

*-- Make up data points
		SELECT DAY(DATE) AS DAY, SUM(Sale) AS Sale FROM (lcDBFPath) WHERE YEAR(DATE) = lnYear AND MONTH(DATE)=lnMonth GROUP BY 1 INTO CURSOR 'cChartPoints'

		GO TOP
		DO WHILE !EOF()
*-- X Axis points
			lnDay = cChartPoints.DAY

*-- Calculate an XL Date from the specified Calendar date (year, month, day)
			lnlXLDate = .oXAxis.oXDate.CalendarDateToXLDate(lnYear, lnMonth, lnDay)

*-- X Axis points
*-- Calculate an XL Date from the specified Calendar date (year, month, day, hour, minute, second)
			IF !EMPTY(laX[1])
				DIMENSION laX[ALEN(laX, 1) + 1]
			ENDIF

			IF !EMPTY(laY[1])
				DIMENSION laY[ALEN(laY, 1) + 1]
			ENDIF

			laX[ALEN(laX, 1)] = lnlXLDate
			laY[ALEN(laY, 1)] = cChartPoints.Sale

			SKIP
		ENDDO


		WITH .oXAxis
*-- Sets the minimum scale value for this X axis. By default this value is set automatically.
			.nScaleMin = .oXDate.CalendarDateToXLDate(IIF(lnMonth = 1, lnYear - 1, lnYear), IIF(lnMonth = 1, 12, lnMonth - 1), 25)
*-- Sets the maximum scale value for this X axis. By default this value is set automatically.
			.nScaleMax = .oXDate.CalendarDateToXLDate(IIF(lnMonth = 12, lnYear + 1, lnYear), IIF(lnMonth = 12, 1, lnMonth + 1), 05)
		ENDWITH

		loMonthlyChartCurve = .AddBar('Sales', @laX, @laY)

		IF !ISNULL(loMonthlyChartCurve)

			WITH loMonthlyChartCurve
				WITH .oBar
					WITH .oFill
						.SetGradientFill(RGB(255, 255, 255), RGB(128,0,64), 2)
					ENDWITH
				ENDWITH
			ENDWITH

		ENDIF

	ENDWITH

	SELECT (lnSelect)

ENDFUNC



